@@ -56,43 +56,26 @@ KMixD : public KDEDModule, protected QDBusContext
    KMixD(QObject* parent, const QList<QVariant>&);
    ~KMixD();
 
-  private:
+  private: 
    void saveBaseConfig();
    void loadConfig();
    void loadBaseConfig();
 
    void initActions();
-   void initActionsLate();
-
-   void fixConfigAfterRead();
-
-  public slots:
-   //void loadVolumes();
-   void saveVolumes();
-   //virtual void applyPrefs( KMixPrefDlg *prefDlg );
 
   private:
-   //KAccel *m_keyAccel;
-   //KAction* _actionShowMenubar;
-
-   bool m_multiDriverMode;         // Not officially supported.
-   bool m_autouseMultimediaKeys;   // Due to message freeze, not in config dialog in KDE4.4
+   bool m_multiDriverMode;
 
    QString m_hwInfoString;
    QString m_defaultCardOnStart;
-   bool m_dontSetDefaultCardOnStart;
    unsigned int m_configVersion;
-   //void increaseOrDecreaseVolume(bool increase);
    QList<QString> m_backendFilter;
 
   private slots:
+   void delayedInitialization();
    void saveConfig();
-   //void slotHWInfo();
    void plugged( const char* driverName, const QString& udi, QString& dev);
    void unplugged( const QString& udi);
-   //void slotIncreaseVolume();
-   //void slotDecreaseVolume();
-   //void slotMute();
 };
 
 #endif // KMIXD_H
